from motor_control import *

# port_name: Windows: "COM*"  Linux: "/dev/ttyUSB*"
# id: Executor ID
# Baudrate: The baud rate can only be 921600
port_name = "COM6"
id = [0x00]
Baudrate = 921600
motor = MotorControl(port_name, id, Baudrate)

# CURRENT_MODE
# Feedback_cycle1(ms): Feedback period of the first status packet，
#                      Including voltage, pwm, current, speed
# Feedback_cycle2(ms)：Feedback period of the second status packet，
#                      Including the position of the motor and the position of the actuator
# Feedback_cycle3(ms)：Feedback period of the third status packet，
#                      Including MOS tube, motor temperature, chip temperature and warning information, 
#                      error information, operation mode
# cur: current(mA)
Feedback_cycle1 = 10
Feedback_cycle2 = 10
Feedback_cycle3 = 10
cur = [1000]

reset(motor)
mode_selection(motor, CURRENT_MODE, Feedback_cycle1, Feedback_cycle2, Feedback_cycle3)
write_current(motor, cur)
current = get_v_p_c_v(motor)[0][-2]     # return the content of the first status packet

# PROFILE_VELOCITY_MODE
# limit_cur(mA): limit current
# vel(rpm): target velocity of motor
limit_cur = [10000]
vel = [1000]

reset(motor)
mode_selection(motor, PROFILE_VELOCITY_MODE, Feedback_cycle1, Feedback_cycle2, Feedback_cycle3)
write_profile_velocity(motor, limit_cur, vel)
velocity = get_v_p_c_v(motor)[0][-1]     # return the content of the first status packet

# PROFILE_POSITION_MODE
# limit_cur(mA): limit current 
# limit_vel(rpm): the limit velocity of motor
# pos(count): target position, With a 16-bit encoder, the actuator counts 65536 per revolution.
limit_cur = [10000]
limit_vel = [1000]
pos = [20000]
reset(motor)
mode_selection(motor, PROFILE_POSITION_MODE, Feedback_cycle1, Feedback_cycle2, Feedback_cycle3)
write_profile_position(motor, limit_cur, limit_vel, {0})
write_profile_position(motor, limit_cur, limit_vel, pos)
position = get_pos(motor)[0][-1]       # return the content of the second status packet
write_profile_position(motor, limit_cur, limit_vel, {0})

# POSITION_MODE
reset(motor)
mode_selection(motor, POSITION_MODE, Feedback_cycle1, Feedback_cycle2, Feedback_cycle3)
write_position(motor, limit_cur, limit_vel, pos)
position = get_pos(motor)[0][-1]       # return the content of the second status packet
write_position(motor, limit_cur, limit_vel, {0})

# MIT mode(Refer to the tutorial on how to use MIT mode)
cur = [1000]
vel = [0]
pos = [0]
kp = [0]
kd = [0]

reset(motor)
mode_selection(motor, MIT_MODE, Feedback_cycle1, Feedback_cycle2, Feedback_cycle3)

# control current
write_mit(motor, cur, vel, pos, kp, kd)
current = get_v_p_c_v(motor)[0][-2]
write_mit(motor, {0}, vel, pos, kp, kd)

# control velocity
kp = [0]
kd = [13.1]
write_mit(motor, {500}, {600}, pos, kp, kd)
velocity = get_v_p_c_v(motor)[0][-1]
write_mit(motor, {0}, {0}, pos, kp, kd)

# control position
kp = [0.09]
kd = [13.1]
write_mit(motor, {0}, {0}, {0}, kp, kd)
write_mit(motor, {310}, {0}, {10000}, kp, kd)
position = get_pos(motor)[0][-1]

# Receive the content of the third status packet
temp_error = get_temp_error(motor)

# For other functions, please refer to the "13. Other functions" section of the document.